@@ -1,4 +1,4 @@
-"mantel.rtest" <- function (m1, m2, nrepet = 99) {
+"mantel.rtest" <- function (m1, m2, nrepet = 99, ...) {
     if (!inherits(m1, "dist")) 
         stop("Object of class 'dist' expected")
     if (!inherits(m2, "dist")) 
@@ -19,7 +19,7 @@
             return(obs)
         perm <- matrix(0, nrow = nrepet, ncol = 1)
         perm <- apply(perm, 1, function(x) cor(unclass(m1), unclass(permutedist(m2))))
-        w <- as.rtest(obs = obs, sim = perm, call = match.call())
+        w <- as.randtest(obs = obs, sim = perm, call = match.call(), subclass = "mantelrtest", ...)
         return(w)
     }
     if (is.euclid(m1) & is.euclid(m2)) {
@@ -30,7 +30,7 @@
         perm <- rep(0, nrepet)
         perm <- unlist(lapply(perm, function(x) cor(dist(tab1[sample(n), 
             ]), m2)))
-        w <- as.rtest(obs = obs, sim = perm, call = match.call())
+        w <- as.randtest(obs = obs, sim = perm, call = match.call(), subclass = "mantelrtest", ...)
         return(w)
     }
     w <- mantelnoneuclid(m1, m2, nrepet = nrepet)
